Module parser

Module parser 

A parser for the Monkey programming language from https://interpreterbook.com/.

Structs

Parser
Consumes input from a lexer::Lexer and produces an ast::Program for the Monkey programming language.

Enums

Error
Specifies the different classes of errors which may occur.
Precedence
Denotes the precedence of various operators.

Type Aliases

Result
A Result type specialized use with for an Error.